==> hazelcast-5.1-sources.jar: com/hazelcast/internal/dynamicconfig/AddDynamicConfigOperationSupplier.java <==
/*
 * Copyright (c) 2008-2022, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.dynamicconfig;

import com.hazelcast.internal.cluster.ClusterService;
import com.hazelcast.nio.serialization.IdentifiedDataSerializable;
import com.hazelcast.spi.impl.operationservice.Operation;

import java.util.function.Supplier;
/**
 * Supplier that creates {@link AddDynamicConfigOperation}s for a given config.
 */
public class AddDynamicConfigOperationSupplier implements Supplier<Operation> {

    private final ClusterService clusterService;
    private final IdentifiedDataSerializable config;

    public AddDynamicConfigOperationSupplier(ClusterService clusterService, IdentifiedDataSerializable config) {
        this.clusterService = clusterService;
        this.config = config;
    }

    @Override
    public Operation get() {
        return new AddDynamicConfigOperation(config, clusterService.getMemberListVersion());
    }
}

==> hazelcast-5.6.0-sources.jar: com/hazelcast/internal/dynamicconfig/AddDynamicConfigOperationSupplier.java <==
/*
 * Copyright (c) 2008-2025, Hazelcast, Inc. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hazelcast.internal.dynamicconfig;

import com.hazelcast.config.UserCodeNamespaceAwareConfig;
import com.hazelcast.internal.cluster.ClusterService;
import com.hazelcast.nio.serialization.IdentifiedDataSerializable;
import com.hazelcast.spi.impl.operationservice.Operation;

/**
 * Supplier that creates {@link AddDynamicConfigOperation}s for a given config.
 */
public class AddDynamicConfigOperationSupplier extends DynamicConfigOperationSupplier {
    public AddDynamicConfigOperationSupplier(ClusterService clusterService, IdentifiedDataSerializable config) {
        super(clusterService, config);
    }

    @Override
    public Operation get() {
        return new AddDynamicConfigOperation(config, clusterService.getMemberListVersion(),
                config instanceof UserCodeNamespaceAwareConfig awareConfig
                        ? awareConfig.getUserCodeNamespace() : null);
    }
}
